/** This class represents a collection of CDs. */
public class CDCollection {
  /** Index of the last CD inserted. */
  private int indexOfLastCD;
  /** Array that holds the CDs. */
  private CD[] CDArray;

  /** Create a CD collections.
   *  @param maxNumOfCDs Maximum number of CDs that can be stored in the
   *                     collection. */
  public CDCollection (int maxNumOfCDs) {
    indexOfLastCD = -1;
    CDArray = new CD[maxNumOfCDs];
  }
  /** Insert a CD.
   *  @param newCD CD to be inserted.
   */
  public void insertCD (CD newCD) {
    if (!isFull()) {
      ++indexOfLastCD;
      CDArray[indexOfLastCD] = newCD;
      System.out.println ("New CD inserted.");
    } else {
      System.out.println ("Collection is full.");
    }
  }

  /** @return Number of CDs in the collection at the moment. */
  public int getNumOfCDs() { return (indexOfLastCD +1); }

  /** @return true if the collection is full. */
  public boolean isFull() { return getNumOfCDs() >= CDArray.length; }

  /** @return true if the collection is empty. */
  public boolean isEmpty() { return (getNumOfCDs() <= 0); }

  /** Print information about the collection. */
  public void printCDCollection() {
    System.out.println("*******************************");
    System.out.println("Number of CDs: " + getNumOfCDs());
    System.out.printf("Value of collection:  %.2f%n",
                        totalValueOfCollection());
    System.out.printf("Average value of a CD:  %.2f%n",
                         averageValueOfCD());
    System.out.println("*******************************");
  }

  /** @return Total value of the CDs in the collection. */
  public double totalValueOfCollection () {
    if (isEmpty()) return 0.0;
    double totalValue = 0.0;
    for (int i = 0; i <= indexOfLastCD; i++) {
      totalValue += CDArray[i].getPrice();
    }
    return totalValue;
  }

  /** @return Average price of a CD. */
  public double averageValueOfCD () {
    if (isEmpty()) return 0.0;
    return totalValueOfCollection() / getNumOfCDs();
  }
}  // End of CDCollection
